@@ -19,7 +19,6 @@ from cloudmesh.shell.command import map_parameters
 # from cloudmesh.common.debug import VERBOSE
 from cloudmesh.burn.Imager import Imager
 from cloudmesh.common.util import yn_choice
-from cloudmesh.common.debug import VERBOSE
 
 
 class BurnCommand(PluginCommand):
@@ -330,7 +329,7 @@ class BurnCommand(PluginCommand):
                        "name",
                        "bs")
 
-        VERBOSE(arguments)
+        # VERBOSE(arguments)
         # arguments.MOUNTPOINT = arguments["--mount"]
         arguments.FORMAT = arguments["--format"]
         arguments.FROM = arguments["--from"]
