@@ -7,7 +7,9 @@ import requests
 import usb
 from cloudmesh.common.util import readfile
 from cloudmesh.common.util import writefile
+from cloudmesh.common.util import path_expand
 from cloudmesh.common.console import Console
+from cloudmesh.common.sudo import Sudo
 
 
 def _get_attribute(attribute, lines):
@@ -25,7 +27,7 @@ class USB(object):
     def __init__(self):
         self.vendors = None
 
-    def get_product(self, vendor, product):
+    def get_product(self, vendor=None, product=None):
         """
         internal method used to retrieve the vendor, product string
         :param vendor: the vendor name
@@ -97,13 +99,13 @@ class USB(object):
         :rtype: str
         """
         filename = 'usb.ids'
-
-        if not os.path.isfile(filename):
+        full_path = path_expand(f"~/.cloudmesh/cmburn/{filename}")
+        if not os.path.isfile(full_path):
             r = requests.get(f'http://www.linux-usb.org/{filename}')
             content = r.text
-            writefile(filename, content)
+            writefile(full_path, content)
         else:
-            content = readfile('usb.ids')
+            content = readfile(full_path)
         return content
 
     @staticmethod
@@ -126,6 +128,7 @@ class USB(object):
         :return: the output from the fdisk command
         :rtype: str
         """
+        Sudo.password()
         return subprocess.getoutput(f"sudo fdisk -l {dev}")
 
     @staticmethod
